# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import supabase_service_pb2 as supabase__service__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in supabase_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SupabaseServiceStub(object):
    """========================================
    Supabase 数据库与向量服务
    ========================================
    Supabase 提供：
    - PostgreSQL 数据库 (完整 SQL 支持)
    - pgvector 向量搜索 (语义搜索、RAG)
    - PostgREST API (自动生成 REST 接口)
    - 实时订阅 (Database changes)
    - 用户认证 (GoTrue Auth)

    本服务封装 Supabase 的核心功能，提供 gRPC 接口

    ========== 数据库操作 (Database CRUD) ==========
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Query = channel.unary_unary(
                '/isa.supabase.SupabaseService/Query',
                request_serializer=supabase__service__pb2.QueryRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.QueryResponse.FromString,
                _registered_method=True)
        self.Insert = channel.unary_unary(
                '/isa.supabase.SupabaseService/Insert',
                request_serializer=supabase__service__pb2.InsertRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.InsertResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/isa.supabase.SupabaseService/Update',
                request_serializer=supabase__service__pb2.UpdateRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.UpdateResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/isa.supabase.SupabaseService/Delete',
                request_serializer=supabase__service__pb2.DeleteRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.DeleteResponse.FromString,
                _registered_method=True)
        self.Upsert = channel.unary_unary(
                '/isa.supabase.SupabaseService/Upsert',
                request_serializer=supabase__service__pb2.UpsertRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.UpsertResponse.FromString,
                _registered_method=True)
        self.ExecuteRPC = channel.unary_unary(
                '/isa.supabase.SupabaseService/ExecuteRPC',
                request_serializer=supabase__service__pb2.RPCRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.RPCResponse.FromString,
                _registered_method=True)
        self.UpsertEmbedding = channel.unary_unary(
                '/isa.supabase.SupabaseService/UpsertEmbedding',
                request_serializer=supabase__service__pb2.UpsertEmbeddingRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.UpsertEmbeddingResponse.FromString,
                _registered_method=True)
        self.SimilaritySearch = channel.unary_unary(
                '/isa.supabase.SupabaseService/SimilaritySearch',
                request_serializer=supabase__service__pb2.SimilaritySearchRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.SimilaritySearchResponse.FromString,
                _registered_method=True)
        self.HybridSearch = channel.unary_unary(
                '/isa.supabase.SupabaseService/HybridSearch',
                request_serializer=supabase__service__pb2.HybridSearchRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.HybridSearchResponse.FromString,
                _registered_method=True)
        self.DeleteEmbedding = channel.unary_unary(
                '/isa.supabase.SupabaseService/DeleteEmbedding',
                request_serializer=supabase__service__pb2.DeleteEmbeddingRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.DeleteEmbeddingResponse.FromString,
                _registered_method=True)
        self.BatchInsert = channel.unary_unary(
                '/isa.supabase.SupabaseService/BatchInsert',
                request_serializer=supabase__service__pb2.BatchInsertRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.BatchInsertResponse.FromString,
                _registered_method=True)
        self.BatchUpsertEmbeddings = channel.unary_unary(
                '/isa.supabase.SupabaseService/BatchUpsertEmbeddings',
                request_serializer=supabase__service__pb2.BatchUpsertEmbeddingsRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.BatchUpsertEmbeddingsResponse.FromString,
                _registered_method=True)
        self.HealthCheck = channel.unary_unary(
                '/isa.supabase.SupabaseService/HealthCheck',
                request_serializer=supabase__service__pb2.HealthCheckRequest.SerializeToString,
                response_deserializer=supabase__service__pb2.HealthCheckResponse.FromString,
                _registered_method=True)


class SupabaseServiceServicer(object):
    """========================================
    Supabase 数据库与向量服务
    ========================================
    Supabase 提供：
    - PostgreSQL 数据库 (完整 SQL 支持)
    - pgvector 向量搜索 (语义搜索、RAG)
    - PostgREST API (自动生成 REST 接口)
    - 实时订阅 (Database changes)
    - 用户认证 (GoTrue Auth)

    本服务封装 Supabase 的核心功能，提供 gRPC 接口

    ========== 数据库操作 (Database CRUD) ==========
    """

    def Query(self, request, context):
        """Query - 查询数据 (SELECT)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Insert(self, request, context):
        """Insert - 插入数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update - 更新数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete - 删除数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upsert(self, request, context):
        """Upsert - 插入或更新 (INSERT ON CONFLICT UPDATE)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteRPC(self, request, context):
        """RPC - 调用 PostgreSQL 函数/存储过程
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertEmbedding(self, request, context):
        """========== 向量操作 (Vector Operations - pgvector) ==========

        UpsertEmbedding - 插入或更新向量嵌入
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimilaritySearch(self, request, context):
        """SimilaritySearch - 向量相似度搜索
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HybridSearch(self, request, context):
        """HybridSearch - 混合搜索 (全文 + 向量)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEmbedding(self, request, context):
        """DeleteEmbedding - 删除向量
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchInsert(self, request, context):
        """========== 批量操作 (Batch Operations) ==========

        BatchInsert - 批量插入
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchUpsertEmbeddings(self, request, context):
        """BatchUpsertEmbeddings - 批量插入向量
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HealthCheck(self, request, context):
        """========== 健康检查 ==========

        HealthCheck - 服务健康检查
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SupabaseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=supabase__service__pb2.QueryRequest.FromString,
                    response_serializer=supabase__service__pb2.QueryResponse.SerializeToString,
            ),
            'Insert': grpc.unary_unary_rpc_method_handler(
                    servicer.Insert,
                    request_deserializer=supabase__service__pb2.InsertRequest.FromString,
                    response_serializer=supabase__service__pb2.InsertResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=supabase__service__pb2.UpdateRequest.FromString,
                    response_serializer=supabase__service__pb2.UpdateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=supabase__service__pb2.DeleteRequest.FromString,
                    response_serializer=supabase__service__pb2.DeleteResponse.SerializeToString,
            ),
            'Upsert': grpc.unary_unary_rpc_method_handler(
                    servicer.Upsert,
                    request_deserializer=supabase__service__pb2.UpsertRequest.FromString,
                    response_serializer=supabase__service__pb2.UpsertResponse.SerializeToString,
            ),
            'ExecuteRPC': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteRPC,
                    request_deserializer=supabase__service__pb2.RPCRequest.FromString,
                    response_serializer=supabase__service__pb2.RPCResponse.SerializeToString,
            ),
            'UpsertEmbedding': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertEmbedding,
                    request_deserializer=supabase__service__pb2.UpsertEmbeddingRequest.FromString,
                    response_serializer=supabase__service__pb2.UpsertEmbeddingResponse.SerializeToString,
            ),
            'SimilaritySearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SimilaritySearch,
                    request_deserializer=supabase__service__pb2.SimilaritySearchRequest.FromString,
                    response_serializer=supabase__service__pb2.SimilaritySearchResponse.SerializeToString,
            ),
            'HybridSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.HybridSearch,
                    request_deserializer=supabase__service__pb2.HybridSearchRequest.FromString,
                    response_serializer=supabase__service__pb2.HybridSearchResponse.SerializeToString,
            ),
            'DeleteEmbedding': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEmbedding,
                    request_deserializer=supabase__service__pb2.DeleteEmbeddingRequest.FromString,
                    response_serializer=supabase__service__pb2.DeleteEmbeddingResponse.SerializeToString,
            ),
            'BatchInsert': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchInsert,
                    request_deserializer=supabase__service__pb2.BatchInsertRequest.FromString,
                    response_serializer=supabase__service__pb2.BatchInsertResponse.SerializeToString,
            ),
            'BatchUpsertEmbeddings': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchUpsertEmbeddings,
                    request_deserializer=supabase__service__pb2.BatchUpsertEmbeddingsRequest.FromString,
                    response_serializer=supabase__service__pb2.BatchUpsertEmbeddingsResponse.SerializeToString,
            ),
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=supabase__service__pb2.HealthCheckRequest.FromString,
                    response_serializer=supabase__service__pb2.HealthCheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'isa.supabase.SupabaseService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('isa.supabase.SupabaseService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SupabaseService(object):
    """========================================
    Supabase 数据库与向量服务
    ========================================
    Supabase 提供：
    - PostgreSQL 数据库 (完整 SQL 支持)
    - pgvector 向量搜索 (语义搜索、RAG)
    - PostgREST API (自动生成 REST 接口)
    - 实时订阅 (Database changes)
    - 用户认证 (GoTrue Auth)

    本服务封装 Supabase 的核心功能，提供 gRPC 接口

    ========== 数据库操作 (Database CRUD) ==========
    """

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/Query',
            supabase__service__pb2.QueryRequest.SerializeToString,
            supabase__service__pb2.QueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Insert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/Insert',
            supabase__service__pb2.InsertRequest.SerializeToString,
            supabase__service__pb2.InsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/Update',
            supabase__service__pb2.UpdateRequest.SerializeToString,
            supabase__service__pb2.UpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/Delete',
            supabase__service__pb2.DeleteRequest.SerializeToString,
            supabase__service__pb2.DeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Upsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/Upsert',
            supabase__service__pb2.UpsertRequest.SerializeToString,
            supabase__service__pb2.UpsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExecuteRPC(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/ExecuteRPC',
            supabase__service__pb2.RPCRequest.SerializeToString,
            supabase__service__pb2.RPCResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpsertEmbedding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/UpsertEmbedding',
            supabase__service__pb2.UpsertEmbeddingRequest.SerializeToString,
            supabase__service__pb2.UpsertEmbeddingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SimilaritySearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/SimilaritySearch',
            supabase__service__pb2.SimilaritySearchRequest.SerializeToString,
            supabase__service__pb2.SimilaritySearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HybridSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/HybridSearch',
            supabase__service__pb2.HybridSearchRequest.SerializeToString,
            supabase__service__pb2.HybridSearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteEmbedding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/DeleteEmbedding',
            supabase__service__pb2.DeleteEmbeddingRequest.SerializeToString,
            supabase__service__pb2.DeleteEmbeddingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchInsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/BatchInsert',
            supabase__service__pb2.BatchInsertRequest.SerializeToString,
            supabase__service__pb2.BatchInsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchUpsertEmbeddings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/BatchUpsertEmbeddings',
            supabase__service__pb2.BatchUpsertEmbeddingsRequest.SerializeToString,
            supabase__service__pb2.BatchUpsertEmbeddingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.supabase.SupabaseService/HealthCheck',
            supabase__service__pb2.HealthCheckRequest.SerializeToString,
            supabase__service__pb2.HealthCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



#!/usr/bin/env python3
"""
Supabase gRPC Client
Supabase 数据库和向量搜索客户端
"""

import sys
from typing import List, Dict, Any, Optional, TYPE_CHECKING
from google.protobuf import struct_pb2

from .base_client import BaseGRPCClient
from .proto import supabase_service_pb2, supabase_service_pb2_grpc, common_pb2

if TYPE_CHECKING:
    from .consul_client import ConsulRegistry


class SupabaseClient(BaseGRPCClient):
    """Supabase gRPC 客户端"""

    def __init__(self, host: Optional[str] = None, port: Optional[int] = None, user_id: Optional[str] = None,
                 lazy_connect: bool = True, enable_compression: bool = True, enable_retry: bool = True,
                 consul_registry: Optional['ConsulRegistry'] = None, service_name_override: Optional[str] = None):
        """
        初始化 Supabase 客户端

        Args:
            host: 服务地址 (optional, will use Consul discovery if not provided)
            port: 服务端口 (optional, will use Consul discovery if not provided)
            user_id: 用户 ID
            lazy_connect: 延迟连接 (默认: True)
            enable_compression: 启用压缩 (默认: True)
            enable_retry: 启用重试 (默认: True)
            consul_registry: ConsulRegistry instance for service discovery (optional)
            service_name_override: Override service name for Consul lookup (optional, defaults to 'supabase')
        """
        super().__init__(
            host=host,
            port=port,
            user_id=user_id,
            lazy_connect=lazy_connect,
            enable_compression=enable_compression,
            enable_retry=enable_retry,
            consul_registry=consul_registry,
            service_name_override=service_name_override
        )
    
    def _create_stub(self):
        """创建 Supabase service stub"""
        return supabase_service_pb2_grpc.SupabaseServiceStub(self.channel)
    
    def service_name(self) -> str:
        return "Supabase"
    
    def _create_metadata(self, org_id: str = 'default_org') -> common_pb2.RequestMetadata:
        """创建请求元数据"""
        return common_pb2.RequestMetadata(
            user_id=self.user_id,
            organization_id=org_id,
            access_token=self.user_id,  # 简化，实际应该是 JWT
            request_id=f'req_{id(self)}',
        )
    
    # ========================================
    # 数据库操作
    # ========================================
    
    def query(self, table: str, select: str = '*', filter: str = '',
              limit: int = 10, order: str = '') -> List[Dict]:
        """
        查询数据

        Args:
            table: 表名
            select: 选择字段
            filter: 过滤条件 (PostgREST 语法)
            limit: 限制数量
            order: 排序

        Returns:
            查询结果列表
        """
        try:
            self._ensure_connected()
            request = supabase_service_pb2.QueryRequest(
                metadata=self._create_metadata(),
                table=table,
                select=select,
                filter=filter,
                limit=limit,
                order=order,
            )
            
            response = self.stub.Query(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 查询成功，返回 {len(response.data)} 条记录")
                return [dict(item) for item in response.data]
            else:
                print(f"❌ [Supabase] 查询失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "查询")
    
    def insert(self, table: str, data: List[Dict]) -> List[Dict]:
        """
        插入数据

        Args:
            table: 表名
            data: 要插入的数据列表

        Returns:
            插入的数据
        """
        try:
            self._ensure_connected()
            # 转换为 protobuf Struct
            structs = []
            for item in data:
                s = struct_pb2.Struct()
                s.update(item)
                structs.append(s)
            
            request = supabase_service_pb2.InsertRequest(
                metadata=self._create_metadata(),
                table=table,
                data=structs,
                return_data=True,
            )
            
            response = self.stub.Insert(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 插入成功，插入了 {response.count} 条记录")
                return [dict(item) for item in response.data]
            else:
                print(f"❌ [Supabase] 插入失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "插入")
    
    def update(self, table: str, data: Dict, filter: str = '') -> List[Dict]:
        """
        更新数据

        Args:
            table: 表名
            data: 要更新的数据
            filter: 过滤条件

        Returns:
            更新后的数据
        """
        try:
            self._ensure_connected()
            # 转换为 protobuf Struct
            s = struct_pb2.Struct()
            s.update(data)
            
            request = supabase_service_pb2.UpdateRequest(
                metadata=self._create_metadata(),
                table=table,
                data=s,
                filter=filter,
                return_data=True,
            )
            
            response = self.stub.Update(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 更新成功，更新了 {response.count} 条记录")
                return [dict(item) for item in response.data]
            else:
                print(f"❌ [Supabase] 更新失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "更新")
    
    def delete(self, table: str, filter: str) -> List[Dict]:
        """
        删除数据

        Args:
            table: 表名
            filter: 过滤条件

        Returns:
            删除的数据
        """
        try:
            self._ensure_connected()
            request = supabase_service_pb2.DeleteRequest(
                metadata=self._create_metadata(),
                table=table,
                filter=filter,
                return_data=True,
            )
            
            response = self.stub.Delete(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 删除成功，删除了 {response.count} 条记录")
                return [dict(item) for item in response.data]
            else:
                print(f"❌ [Supabase] 删除失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "删除")

    def upsert(self, table: str, data: List[Dict], on_conflict: str = 'id') -> List[Dict]:
        """
        插入或更新数据 (UPSERT)

        Args:
            table: 表名
            data: 要插入/更新的数据列表
            on_conflict: 冲突字段 (默认: 'id')

        Returns:
            插入/更新的数据
        """
        try:
            self._ensure_connected()
            # 转换为 protobuf Struct
            structs = []
            for item in data:
                s = struct_pb2.Struct()
                s.update(item)
                structs.append(s)
            
            request = supabase_service_pb2.UpsertRequest(
                metadata=self._create_metadata(),
                table=table,
                data=structs,
                on_conflict=on_conflict,
                return_data=True,
            )
            
            response = self.stub.Upsert(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] Upsert成功，影响了 {response.count} 条记录")
                return [dict(item) for item in response.data]
            else:
                print(f"❌ [Supabase] Upsert失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "Upsert")

    def execute_rpc(self, function_name: str, params: Dict = None) -> Any:
        """
        执行 PostgreSQL 存储过程/函数

        Args:
            function_name: 函数名
            params: 参数字典

        Returns:
            函数返回值
        """
        try:
            self._ensure_connected()
            # 转换参数为 protobuf Struct
            params_struct = struct_pb2.Struct()
            if params:
                params_struct.update(params)
            
            request = supabase_service_pb2.RPCRequest(
                metadata=self._create_metadata(),
                function_name=function_name,
                params=params_struct,
            )
            
            response = self.stub.ExecuteRPC(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] RPC调用成功: {function_name}()")
                # Convert protobuf Value to Python object
                return self._value_to_python(response.data)
            else:
                print(f"❌ [Supabase] RPC调用失败: {response.metadata.error}")
                return None
                
        except Exception as e:
            return self.handle_error(e, f"RPC调用 ({function_name})")

    def batch_insert(self, table: str, data: List[Dict], batch_size: int = 100) -> Dict:
        """
        批量插入数据

        Args:
            table: 表名
            data: 要插入的数据列表
            batch_size: 每批大小

        Returns:
            插入结果统计
        """
        try:
            self._ensure_connected()
            # 转换为 protobuf Struct
            structs = []
            for item in data:
                s = struct_pb2.Struct()
                s.update(item)
                structs.append(s)
            
            request = supabase_service_pb2.BatchInsertRequest(
                metadata=self._create_metadata(),
                table=table,
                data=structs,
                batch_size=batch_size,
            )
            
            response = self.stub.BatchInsert(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 批量插入成功: {response.success_count}/{response.total_count}")
                if response.error_count > 0:
                    print(f"   ⚠️  错误: {response.error_count} 条记录失败")
                return {
                    'total_count': response.total_count,
                    'success_count': response.success_count,
                    'error_count': response.error_count,
                    'errors': list(response.errors)
                }
            else:
                print(f"❌ [Supabase] 批量插入失败: {response.metadata.error}")
                return {}
                
        except Exception as e:
            return self.handle_error(e, "批量插入") or {}

    def _value_to_python(self, value):
        """Convert protobuf Value to Python object"""
        from google.protobuf import json_format
        return json_format.MessageToDict(value)
    
    # ========================================
    # 向量操作 (pgvector)
    # ========================================
    
    def upsert_embedding(self, table: str, doc_id: str, embedding: List[float],
                         metadata: Optional[Dict] = None) -> Optional[str]:
        """
        插入或更新向量

        Args:
            table: 向量表名
            doc_id: 文档 ID
            embedding: 向量 (1536 维)
            metadata: 元数据

        Returns:
            文档 ID 或 None
        """
        try:
            self._ensure_connected()
            # 转换元数据
            meta_struct = struct_pb2.Struct()
            if metadata:
                meta_struct.update(metadata)
            
            request = supabase_service_pb2.UpsertEmbeddingRequest(
                metadata=self._create_metadata(),
                table=table,
                id=doc_id,
                embedding=embedding,
                metadata_json=meta_struct,
            )
            
            response = self.stub.UpsertEmbedding(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 向量插入成功: {response.id}")
                return response.id
            else:
                print(f"❌ [Supabase] 向量插入失败: {response.metadata.error}")
                return None
                
        except Exception as e:
            return self.handle_error(e, "插入向量")
    
    def similarity_search(self, table: str, query_embedding: List[float],
                         limit: int = 10, filter: str = '',
                         threshold: float = 0.5) -> List[Dict]:
        """
        向量相似度搜索

        Args:
            table: 向量表名
            query_embedding: 查询向量
            limit: 返回数量
            filter: 元数据过滤
            threshold: 相似度阈值

        Returns:
            搜索结果列表
        """
        try:
            self._ensure_connected()
            request = supabase_service_pb2.SimilaritySearchRequest(
                metadata=self._create_metadata(),
                table=table,
                query_embedding=query_embedding,
                limit=limit,
                filter=filter,
                metric='cosine',
                threshold=threshold,
            )
            
            response = self.stub.SimilaritySearch(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 相似度搜索成功，找到 {len(response.results)} 个结果")
                results = []
                for result in response.results:
                    results.append({
                        'id': result.id,
                        'similarity': result.similarity,
                        'metadata': dict(result.metadata),
                    })
                return results
            else:
                print(f"❌ [Supabase] 搜索失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "相似度搜索")
    
    def hybrid_search(self, table: str, text_query: str, vector_query: List[float],
                     limit: int = 10, text_weight: float = 0.5,
                     vector_weight: float = 0.5) -> List[Dict]:
        """
        混合搜索 (文本 + 向量)

        Args:
            table: 表名
            text_query: 文本查询
            vector_query: 向量查询
            limit: 返回数量
            text_weight: 文本权重
            vector_weight: 向量权重

        Returns:
            搜索结果列表
        """
        try:
            self._ensure_connected()
            request = supabase_service_pb2.HybridSearchRequest(
                metadata=self._create_metadata(),
                table=table,
                text_query=text_query,
                vector_query=vector_query,
                limit=limit,
                text_weight=text_weight,
                vector_weight=vector_weight,
            )
            
            response = self.stub.HybridSearch(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 混合搜索成功，找到 {len(response.results)} 个结果")
                results = []
                for result in response.results:
                    results.append({
                        'id': result.id,
                        'similarity': result.similarity,
                        'metadata': dict(result.metadata),
                    })
                return results
            else:
                print(f"❌ [Supabase] 搜索失败: {response.metadata.error}")
                return []
                
        except Exception as e:
            return self.handle_error(e, "混合搜索")
    
    def delete_embedding(self, table: str, doc_id: str) -> bool:
        """
        删除向量嵌入

        Args:
            table: 向量表名
            doc_id: 文档 ID

        Returns:
            是否成功删除
        """
        try:
            self._ensure_connected()
            request = supabase_service_pb2.DeleteEmbeddingRequest(
                metadata=self._create_metadata(),
                table=table,
                id=doc_id,
            )
            
            response = self.stub.DeleteEmbedding(request)
            
            if response.metadata.success and response.success:
                print(f"✅ [Supabase] 向量删除成功: {doc_id}")
                return True
            else:
                print(f"❌ [Supabase] 向量删除失败: {response.metadata.error}")
                return False
                
        except Exception as e:
            self.handle_error(e, "删除向量")
            return False

    def batch_upsert_embeddings(self, table: str, embeddings_data: List[Dict]) -> int:
        """
        批量插入向量

        Args:
            table: 表名
            embeddings_data: 向量数据列表 [{'id': ..., 'embedding': ..., 'metadata': ...}]

        Returns:
            成功插入的数量
        """
        try:
            self._ensure_connected()
            embeddings = []
            for data in embeddings_data:
                meta_struct = struct_pb2.Struct()
                meta_struct.update(data.get('metadata', {}))
                
                emb = supabase_service_pb2.EmbeddingData(
                    id=data['id'],
                    embedding=data['embedding'],
                    metadata=meta_struct,
                )
                embeddings.append(emb)
            
            request = supabase_service_pb2.BatchUpsertEmbeddingsRequest(
                metadata=self._create_metadata(),
                table=table,
                embeddings=embeddings,
            )
            
            response = self.stub.BatchUpsertEmbeddings(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 批量插入成功: {response.success_count}/{response.total_count}")
                return response.success_count
            else:
                print(f"❌ [Supabase] 批量插入失败: {response.metadata.error}")
                return 0
                
        except Exception as e:
            return self.handle_error(e, "批量插入向量") or 0
    
    # ========================================
    # 健康检查
    # ========================================
    
    def health_check(self) -> bool:
        """健康检查"""
        try:
            self._ensure_connected()
            request = supabase_service_pb2.HealthCheckRequest(
                metadata=self._create_metadata(),
            )
            
            response = self.stub.HealthCheck(request)
            
            if response.metadata.success:
                print(f"✅ [Supabase] 服务健康")
                print(f"   Supabase 状态: {response.supabase_status}")
                print(f"   PostgreSQL: {response.postgres_version}")
                print(f"   pgvector: {'启用' if response.pgvector_enabled else '禁用'}")
                return True
            else:
                print(f"❌ [Supabase] 服务不健康: {response.metadata.error}")
                return False
                
        except Exception as e:
            return self.handle_error(e, "健康检查") or False


# 便捷使用示例
if __name__ == '__main__':
    # 使用 with 语句自动管理连接
    with SupabaseClient(host='localhost', port=50057, user_id='test_user') as client:
        # 健康检查
        client.health_check()
        
        # 数据库操作
        client.insert('users', [{'name': 'Alice', 'email': 'alice@example.com'}])
        results = client.query('users', select='*', limit=10)
        print(f"查询结果: {results}")
        
        # 向量操作
        import random
        fake_embedding = [random.random() for _ in range(1536)]
        client.upsert_embedding('embeddings', 'doc_001', fake_embedding, 
                               {'title': 'Test Document'})




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: supabase_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'supabase_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16supabase_service.proto\x12\x0cisa.supabase\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa9\x01\n\x0cQueryRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06select\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\r\n\x05order\x18\x05 \x01(\t\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x0e\n\x06offset\x18\x07 \x01(\x05\x12\r\n\x05\x63ount\x18\x08 \x01(\x08\"u\n\rQueryResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x89\x01\n\rInsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0breturn_data\x18\x04 \x01(\x08\"v\n\x0eInsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x99\x01\n\rUpdateRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x13\n\x0breturn_data\x18\x05 \x01(\x08\"v\n\x0eUpdateResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"r\n\rDeleteRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x13\n\x0breturn_data\x18\x04 \x01(\x08\"v\n\x0e\x44\x65leteResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x9e\x01\n\rUpsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bon_conflict\x18\x04 \x01(\t\x12\x13\n\x0breturn_data\x18\x05 \x01(\x08\"v\n\x0eUpsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"{\n\nRPCRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12\'\n\x06params\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"c\n\x0bRPCResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\"\xa5\x01\n\x16UpsertEmbeddingRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x11\n\tembedding\x18\x04 \x03(\x02\x12.\n\rmetadata_json\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x17UpsertEmbeddingResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\"\xb2\x01\n\x17SimilaritySearchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x17\n\x0fquery_embedding\x18\x03 \x03(\x02\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x0e\n\x06metric\x18\x06 \x01(\t\x12\x11\n\tthreshold\x18\x07 \x01(\x02\"}\n\x18SimilaritySearchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x31\n\x07results\x18\x02 \x03(\x0b\x32 .isa.supabase.VectorSearchResult\"_\n\x12VectorSearchResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsimilarity\x18\x02 \x01(\x02\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xc8\x01\n\x13HybridSearchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x12\n\ntext_query\x18\x03 \x01(\t\x12\x14\n\x0cvector_query\x18\x04 \x03(\x02\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x13\n\x0btext_weight\x18\x06 \x01(\x02\x12\x15\n\rvector_weight\x18\x07 \x01(\x02\x12\x0e\n\x06\x66ilter\x18\x08 \x01(\t\"y\n\x14HybridSearchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x31\n\x07results\x18\x02 \x03(\x0b\x32 .isa.supabase.VectorSearchResult\"b\n\x16\x44\x65leteEmbeddingRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"Z\n\x17\x44\x65leteEmbeddingResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\x8d\x01\n\x12\x42\x61tchInsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nbatch_size\x18\x04 \x01(\x05\"\x96\x01\n\x13\x42\x61tchInsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x15\n\rsuccess_count\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rror_count\x18\x04 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"\x8d\x01\n\x1c\x42\x61tchUpsertEmbeddingsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12/\n\nembeddings\x18\x03 \x03(\x0b\x32\x1b.isa.supabase.EmbeddingData\"Y\n\rEmbeddingData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tembedding\x18\x02 \x03(\x02\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa0\x01\n\x1d\x42\x61tchUpsertEmbeddingsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x15\n\rsuccess_count\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rror_count\x18\x04 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"C\n\x12HealthCheckRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"\xa3\x01\n\x13HealthCheckResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x17\n\x0fsupabase_status\x18\x03 \x01(\t\x12\x18\n\x10postgres_version\x18\x04 \x01(\t\x12\x18\n\x10pgvector_enabled\x18\x05 \x01(\x08\x32\xbe\x08\n\x0fSupabaseService\x12@\n\x05Query\x12\x1a.isa.supabase.QueryRequest\x1a\x1b.isa.supabase.QueryResponse\x12\x43\n\x06Insert\x12\x1b.isa.supabase.InsertRequest\x1a\x1c.isa.supabase.InsertResponse\x12\x43\n\x06Update\x12\x1b.isa.supabase.UpdateRequest\x1a\x1c.isa.supabase.UpdateResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.isa.supabase.DeleteRequest\x1a\x1c.isa.supabase.DeleteResponse\x12\x43\n\x06Upsert\x12\x1b.isa.supabase.UpsertRequest\x1a\x1c.isa.supabase.UpsertResponse\x12\x41\n\nExecuteRPC\x12\x18.isa.supabase.RPCRequest\x1a\x19.isa.supabase.RPCResponse\x12^\n\x0fUpsertEmbedding\x12$.isa.supabase.UpsertEmbeddingRequest\x1a%.isa.supabase.UpsertEmbeddingResponse\x12\x61\n\x10SimilaritySearch\x12%.isa.supabase.SimilaritySearchRequest\x1a&.isa.supabase.SimilaritySearchResponse\x12U\n\x0cHybridSearch\x12!.isa.supabase.HybridSearchRequest\x1a\".isa.supabase.HybridSearchResponse\x12^\n\x0f\x44\x65leteEmbedding\x12$.isa.supabase.DeleteEmbeddingRequest\x1a%.isa.supabase.DeleteEmbeddingResponse\x12R\n\x0b\x42\x61tchInsert\x12 .isa.supabase.BatchInsertRequest\x1a!.isa.supabase.BatchInsertResponse\x12p\n\x15\x42\x61tchUpsertEmbeddings\x12*.isa.supabase.BatchUpsertEmbeddingsRequest\x1a+.isa.supabase.BatchUpsertEmbeddingsResponse\x12R\n\x0bHealthCheck\x12 .isa.supabase.HealthCheckRequest\x1a!.isa.supabase.HealthCheckResponseB3Z1github.com/isa-cloud/isa_cloud/api/proto/supabaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'supabase_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/isa-cloud/isa_cloud/api/proto/supabase'
  _globals['_QUERYREQUEST']._serialized_start=118
  _globals['_QUERYREQUEST']._serialized_end=287
  _globals['_QUERYRESPONSE']._serialized_start=289
  _globals['_QUERYRESPONSE']._serialized_end=406
  _globals['_INSERTREQUEST']._serialized_start=409
  _globals['_INSERTREQUEST']._serialized_end=546
  _globals['_INSERTRESPONSE']._serialized_start=548
  _globals['_INSERTRESPONSE']._serialized_end=666
  _globals['_UPDATEREQUEST']._serialized_start=669
  _globals['_UPDATEREQUEST']._serialized_end=822
  _globals['_UPDATERESPONSE']._serialized_start=824
  _globals['_UPDATERESPONSE']._serialized_end=942
  _globals['_DELETEREQUEST']._serialized_start=944
  _globals['_DELETEREQUEST']._serialized_end=1058
  _globals['_DELETERESPONSE']._serialized_start=1060
  _globals['_DELETERESPONSE']._serialized_end=1178
  _globals['_UPSERTREQUEST']._serialized_start=1181
  _globals['_UPSERTREQUEST']._serialized_end=1339
  _globals['_UPSERTRESPONSE']._serialized_start=1341
  _globals['_UPSERTRESPONSE']._serialized_end=1459
  _globals['_RPCREQUEST']._serialized_start=1461
  _globals['_RPCREQUEST']._serialized_end=1584
  _globals['_RPCRESPONSE']._serialized_start=1586
  _globals['_RPCRESPONSE']._serialized_end=1685
  _globals['_UPSERTEMBEDDINGREQUEST']._serialized_start=1688
  _globals['_UPSERTEMBEDDINGREQUEST']._serialized_end=1853
  _globals['_UPSERTEMBEDDINGRESPONSE']._serialized_start=1855
  _globals['_UPSERTEMBEDDINGRESPONSE']._serialized_end=1957
  _globals['_SIMILARITYSEARCHREQUEST']._serialized_start=1960
  _globals['_SIMILARITYSEARCHREQUEST']._serialized_end=2138
  _globals['_SIMILARITYSEARCHRESPONSE']._serialized_start=2140
  _globals['_SIMILARITYSEARCHRESPONSE']._serialized_end=2265
  _globals['_VECTORSEARCHRESULT']._serialized_start=2267
  _globals['_VECTORSEARCHRESULT']._serialized_end=2362
  _globals['_HYBRIDSEARCHREQUEST']._serialized_start=2365
  _globals['_HYBRIDSEARCHREQUEST']._serialized_end=2565
  _globals['_HYBRIDSEARCHRESPONSE']._serialized_start=2567
  _globals['_HYBRIDSEARCHRESPONSE']._serialized_end=2688
  _globals['_DELETEEMBEDDINGREQUEST']._serialized_start=2690
  _globals['_DELETEEMBEDDINGREQUEST']._serialized_end=2788
  _globals['_DELETEEMBEDDINGRESPONSE']._serialized_start=2790
  _globals['_DELETEEMBEDDINGRESPONSE']._serialized_end=2880
  _globals['_BATCHINSERTREQUEST']._serialized_start=2883
  _globals['_BATCHINSERTREQUEST']._serialized_end=3024
  _globals['_BATCHINSERTRESPONSE']._serialized_start=3027
  _globals['_BATCHINSERTRESPONSE']._serialized_end=3177
  _globals['_BATCHUPSERTEMBEDDINGSREQUEST']._serialized_start=3180
  _globals['_BATCHUPSERTEMBEDDINGSREQUEST']._serialized_end=3321
  _globals['_EMBEDDINGDATA']._serialized_start=3323
  _globals['_EMBEDDINGDATA']._serialized_end=3412
  _globals['_BATCHUPSERTEMBEDDINGSRESPONSE']._serialized_start=3415
  _globals['_BATCHUPSERTEMBEDDINGSRESPONSE']._serialized_end=3575
  _globals['_HEALTHCHECKREQUEST']._serialized_start=3577
  _globals['_HEALTHCHECKREQUEST']._serialized_end=3644
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=3647
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=3810
  _globals['_SUPABASESERVICE']._serialized_start=3813
  _globals['_SUPABASESERVICE']._serialized_end=4899
# @@protoc_insertion_point(module_scope)
